@@ -150,8 +150,8 @@ class Gifmaker:
         # get the start position
         # print(chess_game.board() )
 
-        self.white_timeline = []
-        self.black_timeline = []
+        white_timeline = []
+        black_timeline = []
         self.board_states = [Board()]
 
         main_line_itr = chess_game.mainline()
@@ -164,9 +164,9 @@ class Gifmaker:
                 self.board_states.append(current_board)
 
                 if current_board.turn:
-                    self.white_timeline.append(time_left)
+                    white_timeline.append(time_left)
                 else:
-                    self.black_timeline.append(time_left)
+                    black_timeline.append(time_left)
 
                 # White's perspective
                 # print('\n',current_board)
@@ -174,6 +174,15 @@ class Gifmaker:
                 # # Black's perspective
                 # print( '\n',current_board.transform( flip_vertical ))
 
+        # print('Hello')
+
+        
+        print()
+
+        print('White Moves:', white_timeline)
+        print('Black Moves:', black_timeline)
+
+
         obj = Chess_Image(
             colors = self.kwargs['colors'],
             side = self.kwargs['side'],
@@ -185,6 +194,24 @@ class Gifmaker:
         frames = list( map(lambda x: obj.create_position(x), self.board_states) )
 
         durations = len(frames) * [self.kwargs['delay']]
+        white_diffs, black_diffs = [], []
+        for i in range(len(white_timeline) - 1):
+            wd = round(white_timeline[i] - white_timeline[i + 1], 2)
+            bd = round(black_timeline[i] - black_timeline[i + 1], 2)
+            white_diffs.append(wd)
+            black_diffs.append(bd)
+
+        durations = [3, 1, 0.2]
+        for white_time, black_time in zip(white_diffs, black_diffs):
+            durations.append(white_time)
+            durations.append(black_time)
+
+
+
+        print('Durations:', durations)
+        print('No of frames:', len(frames))
+        print('No of delays:', len(durations))
+
 
         mimwrite(
             gif_file_path,
